# -*- coding: utf-8 -*-
"""Tests for the client class."""

from __future__ import absolute_import

import os
import unittest

import requests_mock

from pypingdom import Client
from pypingdom.check import Check


def mock_data(path):
    """Return json data for mocking."""
    dir_path = os.path.dirname(os.path.realpath(__file__))
    resource_file = os.path.join(dir_path, os.path.normpath('resources'), path.lstrip('/'))
    return open(resource_file, mode='r').read()


class ClientTestCase(unittest.TestCase):
    """Test cases for the client methods."""

    @requests_mock.Mocker()
    def test_request(self, m):
        """Test a simple request."""
        base_url = 'https://api.pingdom.com'
        fakepath = '/api/2.0/checks'
        m.request('get', base_url + fakepath, text=mock_data(fakepath))
        fakepath = '/api/2.0/servertime'
        m.request('get', base_url + fakepath, text=mock_data(fakepath))
        fakepath = '/api/2.0/summary.outage/85975'
        m.request('get', base_url + fakepath, text=mock_data(fakepath))

        client = Client(username='username',  # noqa: S106
                        password='password',
                        apikey='apikey',
                        email='email')

        res = client.get_checks()
        self.assertEqual(len(res), 3)
        self.assertTrue(all(isinstance(x, Check) for x in res))
        check1 = client.get_check(name='My check 1')
        self.assertNotEqual(check1, None)
        check2 = client.get_check(name='My check 2')
        self.assertNotEqual(check1, check2)

        res = client.servertime()
        self.assertEqual(res, 1294237910)

        res = client.get_summary_outage('85975')
        self.assertTrue('summary' in res)
        self.assertTrue('states' in res['summary'])

    @requests_mock.Mocker()
    def test_get_checks(self, m):
        """Test a simple request."""
        base_url = 'https://api.pingdom.com'
        fakepath = '/api/2.0/checks'
        m.request('get', base_url + fakepath, text=mock_data(fakepath))

        client = Client(username='username',  # noqa: S106
                        password='password',
                        apikey='apikey',
                        email='email')

        res = client.get_checks()
        self.assertEqual(len(res), 3)
        self.assertTrue(all(isinstance(x, Check) for x in res))

        res = client.get_checks(filters={'tags': ['apache']})
        self.assertEqual(len(res), 1)



#!/usr/sbin/env python
# -*- coding: utf-8 -*-
import yaml
import datetime

from six.moves import input

import pypingdom


with open('private_test_data.yml', 'r') as stream:
    auth = yaml.safe_load(stream)

client = pypingdom.Client(username=auth['username'],
                          password=auth['password'],
                          apikey=auth['apikey'],
                          email=auth['email'])

check_definition = {
    'name': 'Ansible integration test',
    'paused': True,
    # 'alert_policy': '',
    'type': 'http',
    'host': 'www.google.com',
    'url': '/',
    'requestheaders': {
        'XCustom': 'my header value'
    },
    'tags': ['pypingdom-test', 'custom-tag'],
    'encryption': False
}


def clean():
    global client, check_definition
    checks = client.get_checks(filters={'tags': ['pypingdom-test']})
    for check in checks:
        print('deleting check %s' % check.name)  # noqa: T001
        client.delete_check(check)
    checks = client.get_checks(filters={'tags': ['pypingdom-test']})
    print(checks)  # noqa: T001
    assert checks == []  # noqa: S101


def create_check():
    global client, check_definition
    c = client.create_check(check_definition)
    print('created %s' % c.name)  # noqa: T001
    check = client.get_check(check_definition['name'])
    assert check is not None  # noqa: S101


def update_check():
    global client, check_definition
    check = client.get_check(check_definition['name'])
    print('updating check %s' % check.name)  # noqa: T001
    newcheck = client.update_check(check, {'requestheaders': {'XCustom': 'new header value'}})
    assert newcheck.requestheaders['XCustom'] == 'new header value'  # noqa: S101


def delete_check():
    global client, check_definition
    check = client.get_check(check_definition['name'])
    print('deleting check %s' % check.name)  # noqa: T001
    client.delete_check(check)
    check = client.get_check(check_definition['name'])
    assert check is None  # noqa: S101


def create_maintenance():
    global client, check_definition
    check = client.get_check(check_definition['name'])
    start = datetime.datetime.now() + datetime.timedelta(days=2)
    stop = start + datetime.timedelta(minutes=20)
    print('creating maintenance for check %s' % check.name)
    window = client.create_maintenance({
        'checks': [check],
        'name': 'pypyngdom test maintenance',
        'start': start,
        'stop': stop
    })
    return window


def delete_maintenance(mid):
    check = client.get_check(check_definition['name'])
    for m in client.get_maintenances(filters={'checks': [check]}):
        print('deleting maintenance %s' % m.name)  # noqa: T001
        client.delete_maintenance(m)


create_check()
input('Continue?')
update_check()
input('Continue?')
create_maintenance()
input('Continue?')
delete_maintenance()
input('Continue?')
delete_check()
